@@ -8,12 +8,12 @@
 #include <tqpixmap.h>
 #include <tqheader.h>
 
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kdebug.h>
 #include <klineedit.h>
-#include <klocale.h>
-#include <kapplication.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
+#include <tdeglobal.h>
 #include <kiconloader.h>
 
 #include <functional>
@@ -476,7 +476,7 @@ void ListerItem::paintCell ( TQPainter *p, const TQColorGroup &cg,
         alignment &= ~AlignVertical_Mask;
         alignment |= AlignTop;
     }
-    KListViewItem::paintCell( &_p, _cg, column, width, alignment );
+    TDEListViewItem::paintCell( &_p, _cg, column, width, alignment );
     p->drawPixmap( 0, 0, pm );
 }
 
@@ -487,7 +487,7 @@ void Lister::contextMenu( TQListViewItem *it, const TQPoint &pt, int /*c*/ )
     m_context = dynamic_cast< ListerItem * >( it );
     VectorRange sel = selection();
     // entity::Package p = (dynamic_cast<ListerItem *>(it)->entity());
-    KPopupMenu *m = new KPopupMenu (this);
+    TDEPopupMenu *m = new TDEPopupMenu (this);
     utils::Range< Actor > r = actor::Global< entity::Package >::list();
     int id = 8;
     try {
