@@ -4,7 +4,7 @@
 #include <kde_terminal_interface.h>
 #include <adept/dpkgpm-gui.h>
 #include <adept/commitprogressui.h>
-#include <kparts/part.h>
+#include <tdeparts/part.h>
 
 #ifndef EPT_COMMITPROGRESS_H
 #define EPT_COMMITPROGRESS_H
@@ -14,13 +14,13 @@ namespace adept {
 class CommitProgress : public CommitProgressUi
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     CommitProgress( TQWidget *p = 0, const char *n = 0 );
 
     ExtTerminalInterface *terminal() {
         return static_cast<ExtTerminalInterface*>(
-            m_konsole->qt_cast( "ExtTerminalInterface" ) );
+            m_konsole->tqt_cast( "ExtTerminalInterface" ) );
     }
 
     // needs to be called before aptFront::init() :'((
